@@ -34,7 +34,7 @@ class Genbank:
         reverse : bool, optional
             Reverse genome or not
         min_range : Optional[int], optional
-            Min range to be extracted (Default: `1`)
+            Min range to be extracted (Default: `0`)
         max_range : Optional[int], optional
             Max range to be extracted (Default: `genome length`)
         """
@@ -42,13 +42,13 @@ class Genbank:
         self._name = name
         self._records = self._parse_gbk_source(gbk_source)
         self.reverse = reverse
-        self.min_range = 1 if min_range is None else min_range
+        self.min_range = 0 if min_range is None else min_range
         self.max_range = self.full_genome_length if max_range is None else max_range
 
-        if not 1 <= self.min_range <= self.max_range <= self.full_genome_length:
+        if not 0 <= self.min_range <= self.max_range <= self.full_genome_length:
             err_msg = f"min_range={min_range}, max_range={max_range} is invalid. \n"
             err_msg += "Range must be "
-            err_msg += f"'1 <= min_range <= max_range <= {self.full_genome_length}'"
+            err_msg += f"'0 <= min_range <= max_range <= {self.full_genome_length}'"
             raise ValueError(err_msg)
 
     def _parse_gbk_source(
@@ -124,7 +124,7 @@ class Genbank:
     def genome_seq(self) -> str:
         """Range genome sequence"""
         seq = "".join(str(r.seq) for r in self.records)
-        return seq[self.min_range - 1 : self.max_range]
+        return seq[self.min_range : self.max_range]
 
     @lru_cache(maxsize=None)
     def calc_genome_gc_content(self) -> float:
@@ -156,15 +156,14 @@ class Genbank:
             window_size = int(len(seq) / 500)
         if step_size is None:
             step_size = int(len(seq) / 1000)
-        for i in range(0, len(seq), step_size):
-            start_pos = i - int(window_size / 2)
-            start_pos = 0 if start_pos < 0 else start_pos
-            end_pos = i + int(window_size / 2)
-            end_pos = len(seq) if end_pos > len(seq) else end_pos
-            middle_pos = int((end_pos + start_pos) / 2)
-            pos_list.append(middle_pos)
+        pos_list = list(range(0, len(seq), step_size)) + [len(seq)]
+        for pos in pos_list:
+            window_start_pos = pos - int(window_size / 2)
+            window_end_pos = pos + int(window_size / 2)
+            window_start_pos = 0 if window_start_pos < 0 else window_start_pos
+            window_end_pos = len(seq) if window_end_pos > len(seq) else window_end_pos
 
-            subseq = seq[start_pos:end_pos]
+            subseq = seq[window_start_pos:window_end_pos]
             g = subseq.count("G") + subseq.count("g")
             c = subseq.count("C") + subseq.count("c")
             try:
@@ -200,15 +199,14 @@ class Genbank:
             window_size = int(len(seq) / 500)
         if step_size is None:
             step_size = int(len(seq) / 1000)
-        for i in range(0, len(seq), step_size):
-            start_pos = i - int(window_size / 2)
-            start_pos = 0 if start_pos < 0 else start_pos
-            end_pos = i + int(window_size / 2)
-            end_pos = len(seq) if end_pos > len(seq) else end_pos
-            middle_pos = int((end_pos + start_pos) / 2)
-            pos_list.append(middle_pos)
+        pos_list = list(range(0, len(seq), step_size)) + [len(seq)]
+        for pos in pos_list:
+            window_start_pos = pos - int(window_size / 2)
+            window_end_pos = pos + int(window_size / 2)
+            window_start_pos = 0 if window_start_pos < 0 else window_start_pos
+            window_end_pos = len(seq) if window_end_pos > len(seq) else window_end_pos
 
-            subseq = seq[start_pos:end_pos]
+            subseq = seq[window_start_pos:window_end_pos]
             gc_content_list.append(SeqUtils.GC(subseq))
 
         return (np.array(pos_list), np.array(gc_content_list))
@@ -230,7 +228,7 @@ class Genbank:
             Extract target strand
         fix_position : bool, optional
             Fix feature start & end position by specified min_range parameter
-            (fixed_start = start - min_range - 1, fixed_end = end - min_range - 1)
+            (fixed_start = start - min_range, fixed_end = end - min_range)
         allow_partial : bool, optional
             If True, features that are partially included in range are also extracted
 
@@ -240,7 +238,7 @@ class Genbank:
             Extracted features
         """
         extract_features = []
-        min_range, max_range = self.min_range - 1, self.max_range
+        min_range, max_range = self.min_range, self.max_range
         base_len = 0
         for record in self.records:
             features = [f for f in record.features if f.type == feature_type]
