@@ -155,9 +155,13 @@ class GenomeViz:
         labelmargin: float = 0.01,
         linewidth: int = 1,
         linecolor: str = "grey",
+        link_track_ratio: Optional[float] = None,
     ) -> FeatureTrack:
         """Add feature track
 
+        Add feature track, and also add link track between feature tracks
+        if other feature tracks already exist.
+
         Parameters
         ----------
         name : str
@@ -172,6 +176,9 @@ class GenomeViz:
             Track line width
         linecolor : str, optional
             Track line color
+        link_track_ratio : Optional[float], optional
+            Link track ratio. By default, the link_track_ratio value set
+            when GenomeViz was instantiated is used.
 
         Returns
         -------
@@ -184,11 +191,10 @@ class GenomeViz:
             raise ValueError(err_msg)
         # Add link track between feature tracks
         if len(self.get_tracks()) > 0:
-            link_track = LinkTrack(
-                f"{self._tracks[-1].name}-{name}",
-                self.track_spines,
-                self.link_track_ratio,
-            )
+            if link_track_ratio is None:
+                link_track_ratio = self.link_track_ratio
+            link_track_name = f"{self._tracks[-1].name}-{name}"
+            link_track = LinkTrack(link_track_name, self.track_spines, link_track_ratio)
             self._tracks.append(link_track)
         # Add feature track
         feature_track = FeatureTrack(
@@ -204,36 +210,6 @@ class GenomeViz:
         self._tracks.append(feature_track)
         return feature_track
 
-    def add_feature_subtrack(
-        self,
-        feature_track_name: str,
-        subtrack_name: str,
-        ratio: float = 1.0,
-    ) -> None:
-        """Add subtrack of feature track
-
-        Parameters
-        ----------
-        feature_track_name : str
-            Feature track name to be added subtrack
-        subtrack_name : str
-            Subtrack name
-        ratio : float, optional
-            Subtrack size ratio to feature track
-        """
-        feature_track = self.get_track(feature_track_name)
-        if not isinstance(feature_track, FeatureTrack):
-            err_msg = f"'{feature_track_name}' is not FeatureTrack."
-            raise ValueError(err_msg)
-        subtrack_ratio = feature_track.ratio * ratio
-        if subtrack_name in [t.name for t in self.get_tracks(subtrack=True)]:
-            err_msg = f"track.name='{subtrack_name}' is already exists."
-            raise ValueError(err_msg)
-        subtrack = FeatureSubTrack(
-            subtrack_name, feature_track.size, self.track_spines, subtrack_ratio
-        )
-        feature_track.subtracks.append(subtrack)
-
     def add_link(
         self,
         track_link1: Tuple[str, int, int],
@@ -351,7 +327,7 @@ class GenomeViz:
 
     @property
     def top_track(self) -> FeatureTrack:
-        """Top track"""
+        """Top feature track"""
         feature_tracks = [t for t in self.get_tracks() if isinstance(t, FeatureTrack)]
         if len(feature_tracks) == 0:
             err_msg = "No track found. Can't access 'top_track' property."
@@ -360,7 +336,7 @@ class GenomeViz:
 
     @property
     def bottom_track(self) -> FeatureTrack:
-        """Bottom track"""
+        """Bottom feature track"""
         feature_tracks = [t for t in self.get_tracks() if isinstance(t, FeatureTrack)]
         if len(feature_tracks) == 0:
             err_msg = "No track found. Can't access 'bottom_track' property."
@@ -390,6 +366,8 @@ class GenomeViz:
         """
         if len(self.get_tracks()) == 0:
             raise ValueError("No tracks are defined for plotting figure.")
+
+        # Set tick track if required
         self._tracks = [t for t in self.get_tracks() if not isinstance(t, TickTrack)]
         max_track_size = self.max_track_size
         if self.tick_style is not None:
@@ -403,19 +381,21 @@ class GenomeViz:
                 )
             )
 
+        # Set figure
         track_num = len(self.get_tracks(subtrack=True))
         figsize = (self.fig_width, self.fig_track_height * track_num)
+        tight_layout = False if track_num < 3 else True
         figure: Figure = plt.figure(
-            figsize=figsize,
-            facecolor="white",
-            dpi=dpi,
-            tight_layout=False if track_num < 3 else True,
+            figsize=figsize, facecolor="white", dpi=dpi, tight_layout=tight_layout
         )
 
-        track_ratios = [t.ratio for t in self.get_tracks(subtrack=True)]
+        # Set gridspec
+        height_ratios = [t.ratio for t in self.get_tracks(subtrack=True)]
         spec = gridspec.GridSpec(
-            nrows=track_num, ncols=1, height_ratios=track_ratios, hspace=0
+            nrows=track_num, ncols=1, height_ratios=height_ratios, hspace=0
         )
+
+        # Plot each track
         for idx, track in enumerate(self.get_tracks(subtrack=True)):
             # Create new track subplot
             xlim, ylim = (0, max_track_size), track.ylim
